#!/bin/bash

if [ -z "$*" ]; then
    echo "you need to specify a version to build"
    exit 1
fi

if [ "$1" = "-t" ]; then
    shift
    PACKAGESUFFIX=.`date -u +%Y%m%d.%H%M%S`
fi
PACKAGENAME=${1}${PACKAGESUFFIX}

DESTDIR=`pwd`
DESTDIR="$HOME/"

FILE=`basename $0`
DIR_="`pwd` `pwd`/`dirname $0` `dirname $0`"
for i in $DIR_;  do
    [ -x "${i}/${FILE}" ] && DIR=${i}/.. && break
done;

BINFILES="README bin data"
DEVELFILES="extra old rawdata scripts testoutput"

BUILDDIR=`mktemp -td`
echo "Buildtree located @ ${BUILDDIR}"

cd ${BUILDDIR}
mkdir -p ${PACKAGENAME}
echo "Creating base tarballs"
tar cf ${PACKAGENAME}-bin.tar ${PACKAGENAME}
tar cf ${PACKAGENAME}-devel.tar ${PACKAGENAME}
echo "Copying tree"
cp -ra ${DIR}/* ${PACKAGENAME}
echo "Removing data samples that are not intended for the public"
find ${PACKAGENAME}/rawdata -name public -exec grep 'on' \{} -L \; | xargs -r -n1 dirname | xargs -r rm -rf
echo "Removing private info"
find ${PACKAGENAME}/rawdata \( -name '*~' -o -name 'email' -o -name 'machinename' -o -name 'servervars' -o -name 'public' -o -name 'imported' -o -name 'id' -o -name '.htaccess' \) -exec rm \{} \; 

for i in $BINFILES; do
    echo "Adding '$i' to -bin tarball"
    tar rf ${PACKAGENAME}-bin.tar ${PACKAGENAME}/${i}
done
for i in $DEVELFILES; do
    echo "Adding '$i' to -devel tarball"
    tar rf ${PACKAGENAME}-devel.tar ${PACKAGENAME}/${i}
done

echo "Compressing tarballs"
bzip2 -k9v *.tar

echo "Storing tarballs"
mv *.tar.bz2 ${DESTDIR}

echo "Cleaning up buildtree"
cd ${DESTDIR}
rm -rf ${BUILDDIR}
